## cdist-type__pf_apply(7)

### Jake Guffey

`<jake.guffey--@--eprotex.com>`

## 1. NAME

cdist-type__pf_apply - Apply pf(4) ruleset on *BSD

## 2. DESCRIPTION

This type is used on *BSD systems to manage the pf firewall’s active ruleset.

## 3. REQUIRED PARAMETERS

NONE

## 4. OPTIONAL PARAMETERS

NONE

## 5. EXAMPLES

    # Modify the ruleset on $__target_host:
    __pf_ruleset --state present --source /my/pf/ruleset.conf
    require="__pf_ruleset" \
       __pf_apply

    # Remove the ruleset on $__target_host (implies disabling pf(4):
    __pf_ruleset --state absent
    require="__pf_ruleset" \
       __pf_apply

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__pf_ruleset(7)
- pf(4)

## 7. COPYING

Copyright (C) 2012 Jake Guffey. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).